<?php

# PHP cli helper for the openid plugin that adds an unused openid URI onto an 
# existing local user account.
#
# If no arguments are given, the script prints all the users that currently 
# have no openID identifiers associated.
#
# Example use:
# php ./_add_openid.php admin https://login.ubuntu.com/+id/ECzbtPr

@include "wp-config.php";
@include_once "wp-includes/user.php";
@include_once "wp-content/plugins/openid/openid.php";
@include_once "wp-content/plugins/openid/common.php";

# If we don't have args, print the users that need openid
if (count($argv) != 3 ) {
    $users = get_users(array('fields' => 
        array('ID','user_login','user_email','display_name',)));
    foreach ($users as $user) {
        if (!count(get_user_openids($user->ID))) {
            print($user->user_login . "\t" . $user->display_name . ' <' . 
                $user->user_email . ">\n");
        }
    }
    exit(0); # we printed the users without openid!  All done!
}

# We have 2 args, so try to add the supplid OpenID to the user specified.
if (get_user_by_openid($argv[2])) {
    throw new Exception($argv[2] . " already used by user " . get_user_by_openid($argv[2]));
} else {
    $uid = get_userdata_by_various($argv[1]);
    if (!$uid) {
        throw new Exception($argv[1] . " not found!");
    }
    openid_add_identity($uid->ID, $argv[2]);
    print_r(get_user_openids($uid->ID));
}

